# pylib

A repository containing a lot of handy python methods encapsulated on many commonly used build-in modules(os, sys, etc.) or popular libs (numpy, tensorflow, cv2, etc. ).


## What's it for

Forked  from [dengdan/pylib](https://github.com/dengdan/pylib), I made some changes  to compitable with python3, and can be easily use by **pip instal pylib **



#### Upload process

##### Source Distributions
```
python setup.py sdist
```

##### Pure Python Wheels
```
python setup.py bdist_wheel
```

##### Upload your distributions
```
twine upload dist/*
```

